pub struct EndpointSettings {Show 14 fields
pub ipam_config: Option<EndpointIpamConfig>,
pub links: Option<Vec<String>>,
pub mac_address: Option<String>,
pub aliases: Option<Vec<String>>,
pub network_id: Option<String>,
pub endpoint_id: Option<String>,
pub gateway: Option<String>,
pub ip_address: Option<String>,
pub ip_prefix_len: Option<i64>,
pub ipv6_gateway: Option<String>,
pub global_ipv6_address: Option<String>,
pub global_ipv6_prefix_len: Option<i64>,
pub driver_opts: Option<HashMap<String, String>>,
pub dns_names: Option<Vec<String>>,
}Expand description
Configuration for a network endpoint.
Fields
ipam_config: Option<EndpointIpamConfig>links: Option<Vec<String>>mac_address: Option<String>MAC address for the endpoint on this network. The network driver might ignore this parameter.
aliases: Option<Vec<String>>network_id: Option<String>Unique ID of the network.
endpoint_id: Option<String>Unique ID for the service endpoint in a Sandbox.
gateway: Option<String>Gateway address for this network.
ip_address: Option<String>IPv4 address.
ip_prefix_len: Option<i64>Mask length of the IPv4 address.
ipv6_gateway: Option<String>IPv6 gateway address.
global_ipv6_address: Option<String>Global IPv6 address.
global_ipv6_prefix_len: Option<i64>Mask length of the global IPv6 address.
driver_opts: Option<HashMap<String, String>>DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.
dns_names: Option<Vec<String>>List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname. These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending .<network-name>. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.